@@ -1,6 +1,5 @@
-/* -*- Mode: C; c-file-style: "gnu" -*- */
 /* minpg.c - Minimal Privacy Guard (MinPG)
- *        Copyright (C) 2002, 2003 Timo Schulz
+ *        Copyright (C) 2002, 2003, 2004 Timo Schulz
  *
  * This file is part of OpenCDK.
  *
@@ -592,6 +591,8 @@ do_list_sigs (cdk_keydb_hd_t hd, cdk_strlist_t keys)
 	  if (rc)
 	    fprintf (stdout, "check sigs `%s': %s\n", s, cdk_strerror (rc));
 	  do_show_key (pk, hd, 1);
+          if (kstat & CDK_KEY_NOSIGNER)
+            fprintf (stdout, "no signers found in the keyring.\n");
 	}
     }
 
@@ -867,8 +868,9 @@ main (int argc, char ** argv)
   int c = 0, i = 0, sigmode = 0, zip_level = 6;
   int rc = 0, nfiles = 0;
 
-  s = "/home/twoaday/.gnupg/pubring.cdk";
-  /*s = "pubring.gpg";*/
+  cdk_set_log_level (CDK_LOG_DEBUG);
+  /*s = "/home/twoaday/.gnupg/pubring.cdk";*/
+  s = "pubring.gpg";
   rc = cdk_keydb_new (&pub_db, CDK_DBTYPE_PK_KEYRING, s, strlen (s));
   if (rc)
     {
